@@ -11,7 +11,7 @@ k = 2*np.pi / wavelength
 
 N_samp = 1024
 pupil_grid = make_pupil_grid(N_samp, D_tel*N_over)
-aperture = circular_aperture(D_tel)
+aperture = make_circular_aperture(D_tel)
 focal_grid = make_focal_grid(pupil_grid, 1, 500)
 
 fresnel = FresnelPropagator(pupil_grid, distance)
