@@ -110,7 +110,7 @@ def make_focal_grid_from_pupil_grid(pupil_grid, q=1, num_airy=None, focal_length
 		warnings.warn('Focal grid is larger than the maximum allowed angle (fov=%.03f). You may see wrapping when doing propagations.' % np.max(fov), stacklevel=2)
 
 	uv = make_fft_grid(pupil_grid, q, fov)
-	focal_grid = uv.scaled(f_lambda / (2*np.pi))
+	focal_grid = uv.scaled(f_lambda / (2 * np.pi))
 
 	return focal_grid
 
@@ -216,7 +216,7 @@ def make_hexagonal_grid(circum_diameter, n_rings, pointy_top=False, center=None)
 	r = [0]
 
 	for n in range(1, n_rings + 1):
-		#top
+		# top
 		q += list(range(n, 0, -1))
 		r += list(range(0, n))
 		# right top
@@ -358,7 +358,9 @@ def subsample_field(field, subsampling, new_grid=None, statistic='mean'):
 		* 'mean': compute the mean of values for points within each superpixel.
 		* 'sum': compute the sum of values for points within each superpixel. This is identical to a weighted histogram.
 		* 'min': compute the minimum of values for points within each superpixel.
-		* 'max': compute the maximum of values for point within each superpixel.
+		* 'max': compute the maximum of values for points within each superpixel.
+		* 'median': compute the median of values for points within each superpixel.
+		* 'nanmedian': compute the median of values for points within each superpixel while ignoring NaN values.
 
 	Returns
 	-------
@@ -387,7 +389,9 @@ def subsample_field(field, subsampling, new_grid=None, statistic='mean'):
 		'mean': np.mean,
 		'max': np.max,
 		'min': np.min,
-		'sum': np.sum
+		'sum': np.sum,
+		'median': np.median,
+		'nanmedian': np.nanmedian
 	}
 
 	if statistic not in available_statistics:
@@ -398,7 +402,7 @@ def subsample_field(field, subsampling, new_grid=None, statistic='mean'):
 		return Field(available_statistics[statistic](field.reshape(tuple(reshape)), axis=tuple(axes)).reshape(tuple(new_shape)), new_grid)
 	else:
 		# Some weights will be different so calculate weighted mean instead.
-		if statistic in ['min', 'max', 'sum']:
+		if statistic in ['min', 'max', 'sum', 'median', 'nanmedian']:
 			f = available_statistics[statistic](field.reshape(tuple(reshape)), axis=tuple(axes))
 			return Field(f.reshape(tuple(new_shape)), new_grid)
 		else:
